@@ -448,7 +448,7 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     ...     TextSection,
     ...     View,
     ... )
-    >>> from streamlitfront.spec_maker import get_stored_value
+    >>> from streamlitfront.data_binding import BoundData
     >>> 
     >>> convention = {
     ...     APP_KEY: {
@@ -469,7 +469,6 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     ...             'execution': {
     ...                 ELEMENT_KEY: ExecSection,
     ...                 NAME_KEY: 'Execution',
-    ...                 'stored_value_getter': get_stored_value,
     ...                 'inputs': {
     ...                     int: {ELEMENT_KEY: IntInput,},
     ...                     float: {
@@ -478,7 +477,10 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     ...                         'step': 0.01,
     ...                     },
     ...                     Any: {ELEMENT_KEY: TextInput,},
-    ...                     DEFAULT_INPUT_KEY: {NAME_KEY: lambda p: p.name}
+    ...                     DEFAULT_INPUT_KEY: {
+    ...                         NAME_KEY: lambda p: p.name,
+    ...                         'bound_data_factory': BoundData
+    ...                     }
     ...                 },
     ...                 'output': {
     ...                     ELEMENT_KEY: TextOutput,
